# Table of Contents

- [application-modeling-guidelines](<./application-modeling-guidelines.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Application Modeling Guidelines](<./Application-Modeling-Guidelines.md>)
  - [Definition](<./Application-Modeling-Guidelines/Definition.md>)
  - [Description](<./Application-Modeling-Guidelines/Description.md>)
  - [Application Fact Sheet Subtypes](<./Application-Modeling-Guidelines/Application-Fact-Sheet-Subtypes.md>)
  - [Business Application](<./Application-Modeling-Guidelines/Business-Application.md>)
  - [Microservice](<./Application-Modeling-Guidelines/Microservice.md>)
  - [AI Agent](<./Application-Modeling-Guidelines/AI-Agent.md>)
  - [Best Practices for Getting Started](<./Application-Modeling-Guidelines/Best-Practices-for-Getting-Started.md>)
  - [Modeling SaaS Services](<./Application-Modeling-Guidelines/Modeling-SaaS-Services.md>)
  - [Capturing Versions](<./Application-Modeling-Guidelines/Capturing-Versions.md>)
  - [Modeling Hierarchies (Parent / Child Relations)](<./Application-Modeling-Guidelines/Modeling-Hierarchies-Parent--Child-Relations.md>)
  - [Modeling Complex Systems](<./Application-Modeling-Guidelines/Modeling-Complex-Systems.md>)
  - [Modeling External Applications](<./Application-Modeling-Guidelines/Modeling-External-Applications.md>)
  - [Modeling the Underlying Technology of Applications](<./Application-Modeling-Guidelines/Modeling-the-Underlying-Technology-of-Applications.md>)
  - [Capturing the Cost of Applications](<./Application-Modeling-Guidelines/Capturing-the-Cost-of-Applications.md>)
  - [Antipatterns](<./Application-Modeling-Guidelines/Antipatterns.md>)
  - [Applicable Use Cases](<./Application-Modeling-Guidelines/Applicable-Use-Cases.md>)
  - [Insights from the Application Fact Sheet](<./Application-Modeling-Guidelines/Insights-from-the-Application-Fact-Sheet.md>)
  - [Video Tutorial](<./Application-Modeling-Guidelines/Video-Tutorial.md>)
  - [Related Information](<./Application-Modeling-Guidelines/Related-Information.md>)
  - [Was this page helpful?](<./Application-Modeling-Guidelines/Was-this-page-helpful.md>)
